import { ref, reactive } from 'vue';
import { isObject } from '@devops-web/utils';
import { useColumns } from '../useColumns/index.js';

const defaultPagination = () => {
    return {
        current: 1,
        pageSize: 10,
        total: 0,
        showTotal: true,
        showPageSize: true
    };
};
function useTablePage(config) {
    const loading = ref(false);
    const tableData = ref();
    const columnsHooks = useColumns(config.columns);
    const pagination = ref(defaultPagination());
    function onPageChange(current) {
        pagination.value.current = current;
        return getTableData();
    }
    function onPageSizeChange(pageSize) {
        pagination.value.current = 1;
        pagination.value.pageSize = pageSize;
        return getTableData();
    }
    if (isObject(config.pagination)) {
        pagination.value = Object.assign(Object.assign({}, defaultPagination()), config.pagination);
    }
    function getTableData() {
        loading.value = true;
        return config
            .fetch({ pageNum: pagination.value.current, pageSize: pagination.value.pageSize })
            .then((data) => {
            tableData.value = data.records;
            pagination.value.total = data.total;
        })
            .finally(() => {
            loading.value = false;
        });
    }
    /**
     * 刷新表格数据，pagination.pageNum不会变
     */
    function refreshData() {
        return getTableData();
    }
    /**
     * 加载表格数据，pagination.pageNum会设置为1
     */
    function loadTableData() {
        pagination.value.current = 1;
        return getTableData();
    }
    if (config.immediate === true) {
        loadTableData();
    }
    return {
        tableData,
        loading,
        loadTableData,
        refreshData,
        pagination,
        tableInstance: columnsHooks.tableInstance,
        originColumns: columnsHooks.originColumns,
        columns: columnsHooks.columns,
        resetColumns: columnsHooks.resetColumns,
        changeColumnVisibleByPath: columnsHooks.changeColumnVisibleByPath,
        changeColumnVisibleByDataIndex: columnsHooks.changeColumnVisibleByDataIndex,
        updateColumnByPath: columnsHooks.updateColumnByPath,
        updateColumnByDataIndex: columnsHooks.updateColumnByDataIndex,
        replaceColumnByPath: columnsHooks.replaceColumnByPath,
        replaceColumnByDataIndex: columnsHooks.replaceColumnByDataIndex,
        tableConfig: reactive({
            loading,
            data: tableData,
            columns: columnsHooks.columns,
            ref: columnsHooks.ref,
            pagination,
            onPageChange,
            onPageSizeChange
        })
    };
}

export { useTablePage };
