import { ref, reactive } from 'vue';
import { isObject } from '@devops-web/utils';
import { useColumns } from '../useColumns/index.js';

const defaultPagination = () => {
    return {
        current: 1,
        pageSize: 10,
        total: 0,
        showTotal: true,
        showPageSize: true
    };
};
function useTable(config) {
    const loading = ref(false);
    const tableData = ref();
    const columnsHooks = useColumns(config.columns);
    const pagination = ref(false);
    let onPageChange;
    let onPageSizeChange;
    if (config.pagination === true || isObject(config.pagination)) {
        pagination.value = config.pagination === true ? defaultPagination() : Object.assign(Object.assign({}, defaultPagination()), config.pagination);
        onPageChange = (current) => {
            pagination.value.current = current;
        };
        onPageSizeChange = (pageSize) => {
            pagination.value.current = 1;
            pagination.value.pageSize = pageSize;
        };
    }
    /**
     * 加载表格数据
     */
    function loadTableData() {
        loading.value = true;
        return config
            .fetch()
            .then((data) => {
            tableData.value = data;
            if (config.pagination !== false) {
                pagination.value.total = data.length;
            }
        })
            .finally(() => {
            loading.value = false;
        });
    }
    if (config.immediate === true) {
        loadTableData();
    }
    return {
        tableData,
        loading,
        loadTableData,
        pagination,
        tableInstance: columnsHooks.tableInstance,
        originColumns: columnsHooks.originColumns,
        columns: columnsHooks.columns,
        resetColumns: columnsHooks.resetColumns,
        changeColumnVisibleByPath: columnsHooks.changeColumnVisibleByPath,
        changeColumnVisibleByDataIndex: columnsHooks.changeColumnVisibleByDataIndex,
        updateColumnByPath: columnsHooks.updateColumnByPath,
        updateColumnByDataIndex: columnsHooks.updateColumnByDataIndex,
        replaceColumnByPath: columnsHooks.replaceColumnByPath,
        replaceColumnByDataIndex: columnsHooks.replaceColumnByDataIndex,
        tableConfig: reactive({
            loading,
            data: tableData,
            columns: columnsHooks.columns,
            ref: columnsHooks.ref,
            pagination,
            onPageChange,
            onPageSizeChange
        })
    };
}

export { useTable };
